package com.njyunzhi.nanyang.controller;

import com.njyunzhi.nanyang.common.BaseController;
import com.njyunzhi.nanyang.common.OSSUtils;
import com.njyunzhi.nanyang.common.ResponseBean;
import com.njyunzhi.nanyang.config.AliyunConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Map;

//@Api(tags = "通用")
@RestController
@RequestMapping("/{client}")
public class CommController extends BaseController {

    @Autowired
    OSSUtils ossUtils;

    @Autowired
    AliyunConfig aliyunConfig;

    /**
     * 图片
     * @param multipartFile
     * @return
     */
//    @ApiOperation(value = "图片上传", notes = "图片上传")
    @PostMapping("/image")
    public ResponseBean uploadImage(@PathVariable String client,
                                    @RequestParam("file") MultipartFile multipartFile) {
        try {
            String img = ossUtils.putObject(multipartFile);
            return ResponseBean.success(img);
        } catch (IOException e) {
            return ResponseBean.error("上传图片失败: " + e.getMessage(), ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * base64 图片上传
     * @param data
     * @return
     */
//    @ApiOperation(value = "base64 图片上传", notes = "base64 图片上传")
    @PostMapping("/image/base64")
    public ResponseBean uploadBase64Image(@PathVariable String client,
                                          @RequestBody Map<String, String> data) {
        try {
            String base64Str = data.get("base64");
            String img = ossUtils.putObject(base64Str);
            return ResponseBean.success(img);
        } catch (IOException e) {
            return ResponseBean.error("上传图片失败: " + e.getMessage(), ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 获取文件上传凭证
     * @return
     */
//    @ApiOperation(value = "获取文件上传凭证", notes = "获取文件上传凭证")
    @GetMapping("/oss-sts")
    public ResponseBean getOSSSTS(@PathVariable String client) {
        AliyunConfig.Oss oss = aliyunConfig.getOss();

        try {
            Map<String, Object> res = ossUtils.getSTSAKToken();
            res.put("endpoint", oss.getEndpoint());
            res.put("bucket", oss.getBucketName());
            res.put("bucketURL", oss.getBucketURL());
            res.put("region", oss.getRegion());
            res.put("path", getMonth());

            return ResponseBean.success(res);
        } catch (Exception e) {
            return ResponseBean.error("获取上传凭证失败! ", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    private String getMonth() {
        return DateTimeFormatter.ofPattern("yyyy-MM").format(LocalDateTime.now());
    }

}
